==> blancoNLpackGenerator-0.0.34-src.zip: src/blanco/nlpack/generator/csv/record/BlancoNLpackGeneratorDiffResultDetailCsvRecord.java <==
/*
 * ̃\[XR[h blanco Frameworkɂ莩܂B
 */
package blanco.nlpack.generator.csv.record;

/**
 * blancoCsvt@C`쐬ꂽR[hNX<br>
 * t@C`[BlancoNLpackGeneratorDiffResultDetail/blancoNLpackGenerator  ResultDetail ̍킷CSVt@CB]̃R[hNX
 */
public class BlancoNLpackGeneratorDiffResultDetailCsvRecord {
    /**
     * tB[h [BundleUri]
     *
     * ڂ̌^ [java.lang.String]<br>
     * ڔԍ: 1<br>
     * ڂ̐: URI<br>
     * ̓_uNI[gēo͂܂B<br>
     * K{
     */
    private String fBundleUri;

    /**
     * tB[h [Diff]
     *
     * ڂ̌^ [java.lang.String]<br>
     * ڔԍ: 2<br>
     * ڂ̐: Diff<br>
     * ̓_uNI[gēo͂܂B<br>
     * MIN: 3
     */
    private String fDiff;

    /**
     * tB[h [Key]
     *
     * ڂ̌^ [java.lang.String]<br>
     * ڔԍ: 3<br>
     * ڂ̐: Key<br>
     * ̓_uNI[gēo͂܂B<br>
     * MIN: 1
     */
    private String fKey;

    /**
     * tB[h [LeftAction]
     *
     * ڂ̌^ [java.lang.String]<br>
     * ڔԍ: 4<br>
     * ڂ̐: LeftAction<br>
     * ̓_uNI[gēo͂܂B
     */
    private String fLeftAction;

    /**
     * tB[h [LeftInput]
     *
     * ڂ̌^ [java.lang.String]<br>
     * ڔԍ: 5<br>
     * ڂ̐: LeftInput<br>
     * ̓_uNI[gēo͂܂B
     */
    private String fLeftInput;

    /**
     * tB[h [LeftOutput]
     *
     * ڂ̌^ [java.lang.String]<br>
     * ڔԍ: 6<br>
     * ڂ̐: LeftOutput<br>
     * ̓_uNI[gēo͂܂B
     */
    private String fLeftOutput;

    /**
     * tB[h [RightAction]
     *
     * ڂ̌^ [java.lang.String]<br>
     * ڔԍ: 7<br>
     * ڂ̐: RightAction<br>
     * ̓_uNI[gēo͂܂B
     */
    private String fRightAction;

    /**
     * tB[h [RightInput]
     *
     * ڂ̌^ [java.lang.String]<br>
     * ڔԍ: 8<br>
     * ڂ̐: RightInput<br>
     * ̓_uNI[gēo͂܂B
     */
    private String fRightInput;

    /**
     * tB[h [RightOutput]
     *
     * ڂ̌^ [java.lang.String]<br>
     * ڔԍ: 9<br>
     * ڂ̐: RightOutput<br>
     * ̓_uNI[gēo͂܂B
     */
    private String fRightOutput;

    /**
     * tB[h [BundleUri]̃Zb^[\bh
     *
     * ڂ̌^ [java.lang.String]<br>
     * ڔԍ: 1<br>
     * ڂ̐: URI<br>
     * ̓_uNI[gēo͂܂B<br>
     * K{
     *
     * @param argBundleUri tB[h[BundleUri]Ɋi[l
     */
    public void setBundleUri(final String argBundleUri) {
        fBundleUri = argBundleUri;
    }

    /**
     * tB[h[BundleUri]̃Qb^[\bh
     *
     * ڂ̌^ [java.lang.String]<br>
     * ڔԍ: 1<br>
     * ڂ̐: URI<br>
     * ̓_uNI[gēo͂܂B<br>
     * K{
     *
     * @return tB[h[BundleUri]Ɋi[Ăl
     */
    public String getBundleUri() {
        return fBundleUri;
    }

    /**
     * tB[h [Diff]̃Zb^[\bh
     *
     * ڂ̌^ [java.lang.String]<br>
     * ڔԍ: 2<br>
     * ڂ̐: Diff<br>
     * ̓_uNI[gēo͂܂B<br>
     * MIN: 3
     *
     * @param argDiff tB[h[Diff]Ɋi[l
     */
    public void setDiff(final String argDiff) {
        fDiff = argDiff;
    }

    /**
     * tB[h[Diff]̃Qb^[\bh
     *
     * ڂ̌^ [java.lang.String]<br>
     * ڔԍ: 2<br>
     * ڂ̐: Diff<br>
     * ̓_uNI[gēo͂܂B<br>
     * MIN: 3
     *
     * @return tB[h[Diff]Ɋi[Ăl
     */
    public String getDiff() {
        return fDiff;
    }

    /**
     * tB[h [Key]̃Zb^[\bh
     *
     * ڂ̌^ [java.lang.String]<br>
     * ڔԍ: 3<br>
     * ڂ̐: Key<br>
     * ̓_uNI[gēo͂܂B<br>
     * MIN: 1
     *
     * @param argKey tB[h[Key]Ɋi[l
     */
    public void setKey(final String argKey) {
        fKey = argKey;
    }

    /**
     * tB[h[Key]̃Qb^[\bh
     *
     * ڂ̌^ [java.lang.String]<br>
     * ڔԍ: 3<br>
     * ڂ̐: Key<br>
     * ̓_uNI[gēo͂܂B<br>
     * MIN: 1
     *
     * @return tB[h[Key]Ɋi[Ăl
     */
    public String getKey() {
        return fKey;
    }

    /**
     * tB[h [LeftAction]̃Zb^[\bh
     *
     * ڂ̌^ [java.lang.String]<br>
     * ڔԍ: 4<br>
     * ڂ̐: LeftAction<br>
     * ̓_uNI[gēo͂܂B
     *
     * @param argLeftAction tB[h[LeftAction]Ɋi[l
     */
    public void setLeftAction(final String argLeftAction) {
        fLeftAction = argLeftAction;
    }

    /**
     * tB[h[LeftAction]̃Qb^[\bh
     *
     * ڂ̌^ [java.lang.String]<br>
     * ڔԍ: 4<br>
     * ڂ̐: LeftAction<br>
     * ̓_uNI[gēo͂܂B
     *
     * @return tB[h[LeftAction]Ɋi[Ăl
     */
    public String getLeftAction() {
        return fLeftAction;
    }

    /**
     * tB[h [LeftInput]̃Zb^[\bh
     *
     * ڂ̌^ [java.lang.String]<br>
     * ڔԍ: 5<br>
     * ڂ̐: LeftInput<br>
     * ̓_uNI[gēo͂܂B
     *
     * @param argLeftInput tB[h[LeftInput]Ɋi[l
     */
    public void setLeftInput(final String argLeftInput) {
        fLeftInput = argLeftInput;
    }

    /**
     * tB[h[LeftInput]̃Qb^[\bh
     *
     * ڂ̌^ [java.lang.String]<br>
     * ڔԍ: 5<br>
     * ڂ̐: LeftInput<br>
     * ̓_uNI[gēo͂܂B
     *
     * @return tB[h[LeftInput]Ɋi[Ăl
     */
    public String getLeftInput() {
        return fLeftInput;
    }

    /**
     * tB[h [LeftOutput]̃Zb^[\bh
     *
     * ڂ̌^ [java.lang.String]<br>
     * ڔԍ: 6<br>
     * ڂ̐: LeftOutput<br>
     * ̓_uNI[gēo͂܂B
     *
     * @param argLeftOutput tB[h[LeftOutput]Ɋi[l
     */
    public void setLeftOutput(final String argLeftOutput) {
        fLeftOutput = argLeftOutput;
    }

    /**
     * tB[h[LeftOutput]̃Qb^[\bh
     *
     * ڂ̌^ [java.lang.String]<br>
     * ڔԍ: 6<br>
     * ڂ̐: LeftOutput<br>
     * ̓_uNI[gēo͂܂B
     *
     * @return tB[h[LeftOutput]Ɋi[Ăl
     */
    public String getLeftOutput() {
        return fLeftOutput;
    }

    /**
     * tB[h [RightAction]̃Zb^[\bh
     *
     * ڂ̌^ [java.lang.String]<br>
     * ڔԍ: 7<br>
     * ڂ̐: RightAction<br>
     * ̓_uNI[gēo͂܂B
     *
     * @param argRightAction tB[h[RightAction]Ɋi[l
     */
    public void setRightAction(final String argRightAction) {
        fRightAction = argRightAction;
    }

    /**
     * tB[h[RightAction]̃Qb^[\bh
     *
     * ڂ̌^ [java.lang.String]<br>
     * ڔԍ: 7<br>
     * ڂ̐: RightAction<br>
     * ̓_uNI[gēo͂܂B
     *
     * @return tB[h[RightAction]Ɋi[Ăl
     */
    public String getRightAction() {
        return fRightAction;
    }

    /**
     * tB[h [RightInput]̃Zb^[\bh
     *
     * ڂ̌^ [java.lang.String]<br>
     * ڔԍ: 8<br>
     * ڂ̐: RightInput<br>
     * ̓_uNI[gēo͂܂B
     *
     * @param argRightInput tB[h[RightInput]Ɋi[l
     */
    public void setRightInput(final String argRightInput) {
        fRightInput = argRightInput;
    }

    /**
     * tB[h[RightInput]̃Qb^[\bh
     *
     * ڂ̌^ [java.lang.String]<br>
     * ڔԍ: 8<br>
     * ڂ̐: RightInput<br>
     * ̓_uNI[gēo͂܂B
     *
     * @return tB[h[RightInput]Ɋi[Ăl
     */
    public String getRightInput() {
        return fRightInput;
    }

    /**
     * tB[h [RightOutput]̃Zb^[\bh
     *
     * ڂ̌^ [java.lang.String]<br>
     * ڔԍ: 9<br>
     * ڂ̐: RightOutput<br>
     * ̓_uNI[gēo͂܂B
     *
     * @param argRightOutput tB[h[RightOutput]Ɋi[l
     */
    public void setRightOutput(final String argRightOutput) {
        fRightOutput = argRightOutput;
    }

    /**
     * tB[h[RightOutput]̃Qb^[\bh
     *
     * ڂ̌^ [java.lang.String]<br>
     * ڔԍ: 9<br>
     * ڂ̐: RightOutput<br>
     * ̓_uNI[gēo͂܂B
     *
     * @return tB[h[RightOutput]Ɋi[Ăl
     */
    public String getRightOutput() {
        return fRightOutput;
    }

    /**
     * ̃o[IuWFNg̕\擾܂B
     *
     * IuWFNg̃V[͈͂łtoStringȂ_ɒӂėpĂB
     *
     * @return o[IuWFNg̕\B
     */
    public String toString() {
        final StringBuffer buf = new StringBuffer();
        buf.append("blanco.nlpack.generator.csv.record.BlancoNLpackGeneratorDiffResultDetailCsvRecord[");
        buf.append("BundleUri=" + fBundleUri);
        buf.append(",Diff=" + fDiff);
        buf.append(",Key=" + fKey);
        buf.append(",LeftAction=" + fLeftAction);
        buf.append(",LeftInput=" + fLeftInput);
        buf.append(",LeftOutput=" + fLeftOutput);
        buf.append(",RightAction=" + fRightAction);
        buf.append(",RightInput=" + fRightInput);
        buf.append(",RightOutput=" + fRightOutput);
        buf.append("]");
        return buf.toString();
    }
}

==> blancoNLpackGenerator-0.0.94-src.zip: src/blanco/nlpack/generator/csv/record/BlancoNLpackGeneratorDiffResultDetailCsvRecord.java <==
/*
 * ̃\[XR[h blanco Frameworkɂ莩܂B
 */
package blanco.nlpack.generator.csv.record;

/**
 * blancoCsvt@C`쐬ꂽR[hNX<br>
 * t@C`[BlancoNLpackGeneratorDiffResultDetail/blancoNLpackGenerator  ResultDetail ̍킷CSVt@CB]̃R[hNX
 */
public class BlancoNLpackGeneratorDiffResultDetailCsvRecord {
    /**
     * tB[h [BundleUri]
     *
     * ڂ̌^ [java.lang.String]<br>
     * ڔԍ: 1<br>
     * ڂ̐: URI<br>
     * ̓_uNI[gēo͂܂B<br>
     * K{
     */
    private String fBundleUri;

    /**
     * tB[h [Diff]
     *
     * ڂ̌^ [java.lang.String]<br>
     * ڔԍ: 2<br>
     * ڂ̐: Diff<br>
     * ̓_uNI[gēo͂܂B<br>
     * MIN: 3
     */
    private String fDiff;

    /**
     * tB[h [Key]
     *
     * ڂ̌^ [java.lang.String]<br>
     * ڔԍ: 3<br>
     * ڂ̐: Key<br>
     * ̓_uNI[gēo͂܂B<br>
     * MIN: 1
     */
    private String fKey;

    /**
     * tB[h [LeftAction]
     *
     * ڂ̌^ [java.lang.String]<br>
     * ڔԍ: 4<br>
     * ڂ̐: LeftAction<br>
     * ̓_uNI[gēo͂܂B
     */
    private String fLeftAction;

    /**
     * tB[h [LeftInput]
     *
     * ڂ̌^ [java.lang.String]<br>
     * ڔԍ: 5<br>
     * ڂ̐: LeftInput<br>
     * ̓_uNI[gēo͂܂B
     */
    private String fLeftInput;

    /**
     * tB[h [LeftOutput]
     *
     * ڂ̌^ [java.lang.String]<br>
     * ڔԍ: 6<br>
     * ڂ̐: LeftOutput<br>
     * ̓_uNI[gēo͂܂B
     */
    private String fLeftOutput;

    /**
     * tB[h [RightAction]
     *
     * ڂ̌^ [java.lang.String]<br>
     * ڔԍ: 7<br>
     * ڂ̐: RightAction<br>
     * ̓_uNI[gēo͂܂B
     */
    private String fRightAction;

    /**
     * tB[h [RightInput]
     *
     * ڂ̌^ [java.lang.String]<br>
     * ڔԍ: 8<br>
     * ڂ̐: RightInput<br>
     * ̓_uNI[gēo͂܂B
     */
    private String fRightInput;

    /**
     * tB[h [RightOutput]
     *
     * ڂ̌^ [java.lang.String]<br>
     * ڔԍ: 9<br>
     * ڂ̐: RightOutput<br>
     * ̓_uNI[gēo͂܂B
     */
    private String fRightOutput;

    /**
     * tB[h [Note]
     *
     * ڂ̌^ [java.lang.String]<br>
     * ڔԍ: 10<br>
     * ڂ̐: Note<br>
     * ̓_uNI[gēo͂܂B
     */
    private String fNote;

    /**
     * tB[h [BundleUri]̃Zb^[\bh
     *
     * ڂ̌^ [java.lang.String]<br>
     * ڔԍ: 1<br>
     * ڂ̐: URI<br>
     * ̓_uNI[gēo͂܂B<br>
     * K{
     *
     * @param argBundleUri tB[h[BundleUri]Ɋi[l
     */
    public void setBundleUri(final String argBundleUri) {
        fBundleUri = argBundleUri;
    }

    /**
     * tB[h[BundleUri]̃Qb^[\bh
     *
     * ڂ̌^ [java.lang.String]<br>
     * ڔԍ: 1<br>
     * ڂ̐: URI<br>
     * ̓_uNI[gēo͂܂B<br>
     * K{
     *
     * @return tB[h[BundleUri]Ɋi[Ăl
     */
    public String getBundleUri() {
        return fBundleUri;
    }

    /**
     * tB[h [Diff]̃Zb^[\bh
     *
     * ڂ̌^ [java.lang.String]<br>
     * ڔԍ: 2<br>
     * ڂ̐: Diff<br>
     * ̓_uNI[gēo͂܂B<br>
     * MIN: 3
     *
     * @param argDiff tB[h[Diff]Ɋi[l
     */
    public void setDiff(final String argDiff) {
        fDiff = argDiff;
    }

    /**
     * tB[h[Diff]̃Qb^[\bh
     *
     * ڂ̌^ [java.lang.String]<br>
     * ڔԍ: 2<br>
     * ڂ̐: Diff<br>
     * ̓_uNI[gēo͂܂B<br>
     * MIN: 3
     *
     * @return tB[h[Diff]Ɋi[Ăl
     */
    public String getDiff() {
        return fDiff;
    }

    /**
     * tB[h [Key]̃Zb^[\bh
     *
     * ڂ̌^ [java.lang.String]<br>
     * ڔԍ: 3<br>
     * ڂ̐: Key<br>
     * ̓_uNI[gēo͂܂B<br>
     * MIN: 1
     *
     * @param argKey tB[h[Key]Ɋi[l
     */
    public void setKey(final String argKey) {
        fKey = argKey;
    }

    /**
     * tB[h[Key]̃Qb^[\bh
     *
     * ڂ̌^ [java.lang.String]<br>
     * ڔԍ: 3<br>
     * ڂ̐: Key<br>
     * ̓_uNI[gēo͂܂B<br>
     * MIN: 1
     *
     * @return tB[h[Key]Ɋi[Ăl
     */
    public String getKey() {
        return fKey;
    }

    /**
     * tB[h [LeftAction]̃Zb^[\bh
     *
     * ڂ̌^ [java.lang.String]<br>
     * ڔԍ: 4<br>
     * ڂ̐: LeftAction<br>
     * ̓_uNI[gēo͂܂B
     *
     * @param argLeftAction tB[h[LeftAction]Ɋi[l
     */
    public void setLeftAction(final String argLeftAction) {
        fLeftAction = argLeftAction;
    }

    /**
     * tB[h[LeftAction]̃Qb^[\bh
     *
     * ڂ̌^ [java.lang.String]<br>
     * ڔԍ: 4<br>
     * ڂ̐: LeftAction<br>
     * ̓_uNI[gēo͂܂B
     *
     * @return tB[h[LeftAction]Ɋi[Ăl
     */
    public String getLeftAction() {
        return fLeftAction;
    }

    /**
     * tB[h [LeftInput]̃Zb^[\bh
     *
     * ڂ̌^ [java.lang.String]<br>
     * ڔԍ: 5<br>
     * ڂ̐: LeftInput<br>
     * ̓_uNI[gēo͂܂B
     *
     * @param argLeftInput tB[h[LeftInput]Ɋi[l
     */
    public void setLeftInput(final String argLeftInput) {
        fLeftInput = argLeftInput;
    }

    /**
     * tB[h[LeftInput]̃Qb^[\bh
     *
     * ڂ̌^ [java.lang.String]<br>
     * ڔԍ: 5<br>
     * ڂ̐: LeftInput<br>
     * ̓_uNI[gēo͂܂B
     *
     * @return tB[h[LeftInput]Ɋi[Ăl
     */
    public String getLeftInput() {
        return fLeftInput;
    }

    /**
     * tB[h [LeftOutput]̃Zb^[\bh
     *
     * ڂ̌^ [java.lang.String]<br>
     * ڔԍ: 6<br>
     * ڂ̐: LeftOutput<br>
     * ̓_uNI[gēo͂܂B
     *
     * @param argLeftOutput tB[h[LeftOutput]Ɋi[l
     */
    public void setLeftOutput(final String argLeftOutput) {
        fLeftOutput = argLeftOutput;
    }

    /**
     * tB[h[LeftOutput]̃Qb^[\bh
     *
     * ڂ̌^ [java.lang.String]<br>
     * ڔԍ: 6<br>
     * ڂ̐: LeftOutput<br>
     * ̓_uNI[gēo͂܂B
     *
     * @return tB[h[LeftOutput]Ɋi[Ăl
     */
    public String getLeftOutput() {
        return fLeftOutput;
    }

    /**
     * tB[h [RightAction]̃Zb^[\bh
     *
     * ڂ̌^ [java.lang.String]<br>
     * ڔԍ: 7<br>
     * ڂ̐: RightAction<br>
     * ̓_uNI[gēo͂܂B
     *
     * @param argRightAction tB[h[RightAction]Ɋi[l
     */
    public void setRightAction(final String argRightAction) {
        fRightAction = argRightAction;
    }

    /**
     * tB[h[RightAction]̃Qb^[\bh
     *
     * ڂ̌^ [java.lang.String]<br>
     * ڔԍ: 7<br>
     * ڂ̐: RightAction<br>
     * ̓_uNI[gēo͂܂B
     *
     * @return tB[h[RightAction]Ɋi[Ăl
     */
    public String getRightAction() {
        return fRightAction;
    }

    /**
     * tB[h [RightInput]̃Zb^[\bh
     *
     * ڂ̌^ [java.lang.String]<br>
     * ڔԍ: 8<br>
     * ڂ̐: RightInput<br>
     * ̓_uNI[gēo͂܂B
     *
     * @param argRightInput tB[h[RightInput]Ɋi[l
     */
    public void setRightInput(final String argRightInput) {
        fRightInput = argRightInput;
    }

    /**
     * tB[h[RightInput]̃Qb^[\bh
     *
     * ڂ̌^ [java.lang.String]<br>
     * ڔԍ: 8<br>
     * ڂ̐: RightInput<br>
     * ̓_uNI[gēo͂܂B
     *
     * @return tB[h[RightInput]Ɋi[Ăl
     */
    public String getRightInput() {
        return fRightInput;
    }

    /**
     * tB[h [RightOutput]̃Zb^[\bh
     *
     * ڂ̌^ [java.lang.String]<br>
     * ڔԍ: 9<br>
     * ڂ̐: RightOutput<br>
     * ̓_uNI[gēo͂܂B
     *
     * @param argRightOutput tB[h[RightOutput]Ɋi[l
     */
    public void setRightOutput(final String argRightOutput) {
        fRightOutput = argRightOutput;
    }

    /**
     * tB[h[RightOutput]̃Qb^[\bh
     *
     * ڂ̌^ [java.lang.String]<br>
     * ڔԍ: 9<br>
     * ڂ̐: RightOutput<br>
     * ̓_uNI[gēo͂܂B
     *
     * @return tB[h[RightOutput]Ɋi[Ăl
     */
    public String getRightOutput() {
        return fRightOutput;
    }

    /**
     * tB[h [Note]̃Zb^[\bh
     *
     * ڂ̌^ [java.lang.String]<br>
     * ڔԍ: 10<br>
     * ڂ̐: Note<br>
     * ̓_uNI[gēo͂܂B
     *
     * @param argNote tB[h[Note]Ɋi[l
     */
    public void setNote(final String argNote) {
        fNote = argNote;
    }

    /**
     * tB[h[Note]̃Qb^[\bh
     *
     * ڂ̌^ [java.lang.String]<br>
     * ڔԍ: 10<br>
     * ڂ̐: Note<br>
     * ̓_uNI[gēo͂܂B
     *
     * @return tB[h[Note]Ɋi[Ăl
     */
    public String getNote() {
        return fNote;
    }

    /**
     * ̃o[IuWFNg̕\擾܂B
     *
     * IuWFNg̃V[͈͂łtoStringȂ_ɒӂėpĂB
     *
     * @return o[IuWFNg̕\B
     */
    public String toString() {
        final StringBuffer buf = new StringBuffer();
        buf.append("blanco.nlpack.generator.csv.record.BlancoNLpackGeneratorDiffResultDetailCsvRecord[");
        buf.append("BundleUri=" + fBundleUri);
        buf.append(",Diff=" + fDiff);
        buf.append(",Key=" + fKey);
        buf.append(",LeftAction=" + fLeftAction);
        buf.append(",LeftInput=" + fLeftInput);
        buf.append(",LeftOutput=" + fLeftOutput);
        buf.append(",RightAction=" + fRightAction);
        buf.append(",RightInput=" + fRightInput);
        buf.append(",RightOutput=" + fRightOutput);
        buf.append(",Note=" + fNote);
        buf.append("]");
        return buf.toString();
    }
}
